testcontract

package
v0.1.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 9, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package testcontract contains reusable contract tests for stores and filters.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ContractTenant

func ContractTenant(id types.TenantID) types.Tenant

ContractTenant returns valid tenant metadata for contract tests.

func RunStoreContract

func RunStoreContract(t *testing.T, factory StoreFactory)

RunStoreContract verifies common Store behavior.

Types

type StoreFactory

type StoreFactory func() store.Store

StoreFactory creates an empty Store implementation for contract tests.

Jump to